"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const CompositeConstraint_1 = require("../../src/constraints/CompositeConstraint");
const FieldValueConstraint_1 = require("../../src/constraints/FieldValueConstraint");
const data = {
    variant: 'android',
    appName: 'test123',
    serverKey: 'sdfsdfds',
    nested: {
        key1: 'value1',
        key2: 'value2',
        key3: 'value3',
        nested: {
            key11: 'value11',
            key22: 'value22',
            key33: 'value33',
        },
    },
};
describe('CompositeConstraint', () => {
    it('ALL - should return false - nested.key2', () => {
        const config = {
            type: CompositeConstraint_1.NAME,
            subRules: [
                {
                    type: FieldValueConstraint_1.NAME,
                    path: 'nested.key1',
                    value: 'value1',
                },
                {
                    type: FieldValueConstraint_1.NAME,
                    path: 'nested.key2',
                    value: 'value1',
                },
            ],
        };
        const constraint = new CompositeConstraint_1.CompositeConstraint(config);
        expect(constraint.isRespected(data)).toBe(false);
    });
    it('ALL - should return false - nested.key1', () => {
        const config = {
            type: CompositeConstraint_1.NAME,
            subRules: [
                {
                    type: FieldValueConstraint_1.NAME,
                    path: 'nested.key1',
                    value: 'value2',
                },
                {
                    type: FieldValueConstraint_1.NAME,
                    path: 'nested.key2',
                    value: 'value2',
                },
            ],
        };
        const constraint = new CompositeConstraint_1.CompositeConstraint(config);
        expect(constraint.isRespected(data)).toBe(false);
    });
    it('ALL - should return true', () => {
        const config = {
            type: CompositeConstraint_1.NAME,
            subRules: [
                {
                    type: FieldValueConstraint_1.NAME,
                    path: 'nested.key1',
                    value: 'value1',
                },
                {
                    type: FieldValueConstraint_1.NAME,
                    path: 'nested.key2',
                    value: 'value2',
                },
            ],
        };
        const constraint = new CompositeConstraint_1.CompositeConstraint(config);
        expect(constraint.isRespected(data)).toBe(true);
    });
    it('ANY - should return true - nested.key2', () => {
        const config = {
            type: CompositeConstraint_1.NAME,
            algorithm: 'any',
            subRules: [
                {
                    type: FieldValueConstraint_1.NAME,
                    path: 'nested.key1',
                    value: 'value2',
                },
                {
                    type: FieldValueConstraint_1.NAME,
                    path: 'nested.key2',
                    value: 'value2',
                },
            ],
        };
        const constraint = new CompositeConstraint_1.CompositeConstraint(config);
        expect(constraint.isRespected(data)).toBe(true);
    });
    it('ANY - should return false', () => {
        const config = {
            type: CompositeConstraint_1.NAME,
            algorithm: 'any',
            subRules: [
                {
                    type: FieldValueConstraint_1.NAME,
                    path: 'nested.key1',
                    value: 'value3',
                },
                {
                    type: FieldValueConstraint_1.NAME,
                    path: 'nested.key2',
                    value: 'value3',
                },
            ],
        };
        const constraint = new CompositeConstraint_1.CompositeConstraint(config);
        expect(constraint.isRespected(data)).toBe(false);
    });
});
//# sourceMappingURL=CompositeConstraint.test.js.map